@@ -1865,10 +1865,10 @@ launcher_plugin_button_update (LauncherPlugin *plugin)
     }
   else
     {
-      /* set missing image icon */
+      /* set fallback icon if there is no application icon (yet) */
       panel_return_if_fail (GTK_IS_WIDGET (plugin->child));
       gtk_image_set_from_icon_name (GTK_IMAGE (plugin->child),
-                                    "image-missing", icon_size);
+                                    "org.xfce.panel.launcher", icon_size);
     }
 }
 
@@ -1981,6 +1981,8 @@ launcher_plugin_button_press_event (GtkWidget      *button,
                                       launcher_plugin_menu_popup_destroyed);
     }
 
+  gtk_widget_set_state_flags (button, GTK_STATE_FLAG_CHECKED, FALSE);
+
   return FALSE;
 }
 
@@ -2017,6 +2019,8 @@ launcher_plugin_button_release_event (GtkWidget      *button,
   else
     return TRUE;
 
+  gtk_widget_set_state_flags (button, GTK_STATE_FLAG_NORMAL, TRUE);
+
   return FALSE;
 }
 
